@@ -869,14 +869,15 @@ class Message(ABC):
         logger.info(f'[校验成功,response.code 实际值:{self.code} == 预期值：{code}]')
         return self
     
-    def check_values(self, expect_val, actual_val):
+    def check_values(self, expect_val, actual_val, desc):
         """
         check response data
         @expect_val : 预期值
         @actual_val : 实际值,取自response data
+        @desc : 描述校验信息
         """
-        assert actual_val == expect_val, f'[校验失败,实际值:{actual_val} == 预期值：{expect_val}]'
-        logger.info(f'[校验成功,实际值:{actual_val} == 预期值：{expect_val}]')
+        assert actual_val == expect_val, f'[校验失败,{desc} 实际值:{actual_val} == 预期值：{expect_val}]'
+        logger.info(f'[校验成功,{desc} 实际值:{actual_val} == 预期值：{expect_val}]')
         return self
 
 
@@ -1037,20 +1038,20 @@ class ServiceStub(ABC):
     Base class for async twirp service stubs.
     """
     session.host = None
-    session.suffix_url = None
     session.common_args = None
     
     def __init__(self, target: str = None, common_args: Dict[str, str] = {}):
-        self._common_args = common_args
-        if session.suffix_url is None:
-            session.suffix_url = "?" + urlencode(self._common_args)
-        self.suffix_url = session.suffix_url
+        if len(common_args) > 0:
+            if session.common_args is None:
+                session.common_args = common_args
+            if session.common_args.get('access_key') != common_args.get('access_key'):
+                session.common_args = common_args
+        
+        self.suffix_url = "?" + urlencode(session.common_args)
+        
         if session.host is None:
             session.host = target
         self._target = session.host
-        
-        if session.common_args is None:
-            session.common_args = common_args
     
     def _do_twirp_rpc(self, api, request: Message, response: Message):
         api = api + self.suffix_url
